.. WDOM documentation master file, created by
   sphinx-quickstart on Mon Jan 11 18:49:13 2016.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

.. include:: ../README.rst

About This Document
-------------------

This document is still incomplete, and will contain typos and bad descriptions.
Furthermore, my English is so bad, so if you find any incorrect expression,
please let me know at `issues <https://github.com/miyakogi/wdom/issues>`_ or
send `PR <https://github.com/miyakogi/wdom/pulls>`_. Any small
improvements/suggestions (e.g. just changing **a** to **the**) are welcome! 

Contents
--------

.. toctree::
    :titlesonly:

    guide/index
    reference
    changes


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _DOM specification: https://dom.spec.whatwg.org/
.. _Selenium: http://selenium-python.readthedocs.org/
.. _tornado: http://www.tornadoweb.org/en/stable/
.. _aiohttp: http://aiohttp.readthedocs.org/en/stable/
